@@ -1005,20 +1005,20 @@ class ShadowstepImage:
         max_attempts: int = 10,
         step_delay: float = 0.5,
     ) -> ShadowstepImage:
-        """Internal method to scroll in a direction until image is found.
+        """Scroll the screen in the specified direction until the image is found.
 
         Args:
-            direction: "up", "down", "left", or "right".
-            from_percent: Starting position (for down/right).
-            to_percent: Ending position (for down/right).
-            max_attempts: Maximum scroll attempts.
-            step_delay: Delay between attempts.
+            direction: Scroll direction: "up", "down", "left", or "right".
+            from_percent: Starting position for down/right scrolls.
+            to_percent: Ending position for down/right scrolls.
+            max_attempts: Maximum number of scroll attempts.
+            step_delay: Delay between attempts in seconds.
 
         Returns:
-            ShadowstepImage: Self for method chaining.
+            ShadowstepImage: Instance for call chaining.
 
         Raises:
-            ShadowstepImageNotFoundError: If image not found after max_attempts.
+            ShadowstepImageNotFoundError: Raised when the image is not found after max_attempts.
 
         """
         for attempt in range(max_attempts):
